#!/bin/sh

# THIS PRODUCT CONTAINS RESTRICTED MATERIALS OF IBM
# 5724-I04 (C) COPYRIGHT International Business Machines Corp., 2005
# All Rights Reserved * Licensed Materials - Property of IBM
# US Government Users Restricted Rights - Use, duplication or disclosure
# restricted by GSA ADP Schedule Contract with IBM Corp.

# ifix launcher
thisHostname=`hostname -s`
thisDir=`dirname "$0"`
errorsduringinstall=0

if [ ! $2 ]
then
  if [ -f ./LI70692.sh ]
  then
  echo "IfixLI70692: WVS IfixLI70692 Installer  "
  echo " to install ifix  syntax: ifix_LI70692.sh -install "
  echo " to uninstall ifix  syntax: ifix_LI70692.sh -uninstall "
  echo " "
  exit -1
  fi
fi

if [ $# -eq 0 ]
then
 echo "IfixLI70692: WVS IfixLI70692 Installer  "
 echo " to install ifix  syntax: ifix_LI70692.sh -install "
 echo " to uninstall ifix  syntax: ifix_LI70692.sh -uninstall "
 echo " "
 exit -1
fi

if [ -f /opt/WebSphere/AppServer/bin/setupCmdLine.sh ]
then
   source /opt/WebSphere/AppServer/bin/setupCmdLine.sh
fi

if [ ! "$WAS_HOME" ] ; then
   echo "IfixLI70692: Please run WebSphere Application Server's setupCmdLine.sh to setup"
   echo "             the WAS Command line environment - see the Readme file for command syntax"
  exit -1
fi
if [ ! "$WVS_ROOT" ] ; then
   echo "IfixLI70692: Please configure WebSphere Voice Server wvs.setenv according"
   echo "             to the WVS InfoCenter "
  exit -1
fi

if [ ! -f $WVS_ROOT/itlm/WVSBASEE050102.SYS ] ; then
   echo "IfixLI70692: The level of the installed WebSphere Voice Server is not 5.1.2"
   echo "             The ifix will not be applied. "
  exit -1
fi

isInstallOption=false
isUnInstallOption=false
nonJavaOptionCount=1
for option in "$@" ; do
  if [ "$option" = "-install" ] ; then
     isInstallOption=true
  else
     if [ "$option" = "-uninstall" ] ; then
        isUnInstallOption=true
     fi
  fi
done

if [ "$isInstallOption" = "true" ] ; then
  if [ -f $WVS_ROOT/ifix/LI70692/wvsapp.ear.bak ] ; then
    echo "ifixLI70692: Ifix LI70692 is applied, please uninstall before trying to reinstall ifix"
    exit -1
  fi
fi

if [ "$isInstallOption" = "true" ] ; then
 # Check that the ifix files are found
 echo "ifixLI70692: Checking for ifix files ..."
  if [ -f $thisDir/wvsapp.ear ] ; then
      echo "ifixLI70692: Ifix files found.. proceeding to install ifix"
      mkdir -p $WVS_ROOT/ifix/LI70692
      cp -p $thisDir/LI70692.sh $WVS_ROOT/ifix/ifix_LI70692.sh
      cp -p $thisDir/stopVoiceServer.jacl $WVS_ROOT/ifix/LI70692/.
      cp -p $WVS_ROOT/ear/wvsapp.ear $WVS_ROOT/ifix/LI70692/wvsapp.ear.bak
      cp -p $WVS_ROOT/.package/installEar.jacl $WVS_ROOT/ifix/LI70692/installEar.jacl.bak
      
      echo "ifixLI70692: Stopping WebSphere Application Server"
      $WAS_HOME/bin/stopServer.sh server1
      
      if [ "$?" = "246" -o "$?" = "0" ] ; then
         echo "Ifix_LI70692: Application Server stopped successful, proceeding to install ifix"
      else
         echo "Ifix_LI70692: Application Server reported failure during stopping. Ifix installation will not continue"
         rm -rf $WVS_ROOT/ifix/LI70692
         exit -1
      fi
      
      cp -fbp $thisDir/wvsapp.ear $WVS_ROOT/ear/. 
      cp -fbp $thisDir/installEar.jacl $WVS_ROOT/.package/.
      cp -fbp $thisDir/configureWVR.sh $WAS_HOME/bin/.
      cp -fbp $thisDir/configureWVR.jacl $WAS_HOME/bin/.
      
      chmod 755 $WAS_HOME/bin/configureWVR.sh

      echo "ifixLI70692: Starting WebSphere Application Server"
      $WAS_HOME/bin/startServer.sh server1 -quiet
      if [ "$?" = "111" -o "$?" = "0" ] ; then
         echo "Ifix_LI70692: Application Server started successful, proceeding to install ifix"
      else
         echo "Ifix_LI70692: Application Server reported failure during starting. Ifix installation was not successful. Please uninstall"
         exit -1
      fi
      
      echo "ifixLI70692: Stopping  WebSphere Voice Server"
      $WAS_HOME/bin/wsadmin.sh -f $thisDir/stopVoiceServer.jacl $thisHostname
      errorsduringinstall=$?
      
      echo "ifixLI70692: Updating WebSphere Voice Server J2EE Application"
      $WAS_HOME/bin/wsadmin.sh -f $WVS_ROOT/.package/installEar.jacl $WVS_ROOT/ear wvsapp WVS5.1-$thisHostname $thisHostname
      errorsduringinstall=$?
      
      if [ $errorsduringinstall = "0" ] ; then
        echo " "
        echo " "
        echo " "
        echo "Ifix_LI70692: Ifix is now applied, please reboot the system"
        echo " "
        echo " "
      else
        echo " "
        echo " "
        echo " "
        echo "Ifix_LI70692: Ifix installation was not successful. Please uninstall. "
        echo " "
      fi
  else
      echo "ifixLI70692: Ifix files missing, please be sure this script is in same directory as the binary files" 
  fi
  cp $thisDir/LI70692.log $WVS_ROOT/log/.
fi

if [ "$isUnInstallOption" = "true" ] ; then
 # Check that the ifix backup files are found
 echo "ifixLI70692: Checking for ifix backup files ..."
  if [ -f $WVS_ROOT/ifix/LI70692/wvsapp.ear.bak ] ; then
      echo "ifixLI70692: Ifix backup files found.. proceeding to un-install ifix"

      echo "ifixLI70692: Starting WebSphere Application Server"
      $WAS_HOME/bin/startServer.sh server1 -quiet
      if [ "$?" = "111" -o "$?" = "0" ] ; then
         echo "Ifix_LI70692: Application Server started successful, proceeding to uninstall ifix"
      else
         echo "Ifix_LI70692: Application Server reported failure during starting. Ifix uninstallation was not successful. Please contact support"
         exit -1
      fi

      echo "ifixLI70692: Stopping  WebSphere Voice Server"
      $WAS_HOME/bin/wsadmin.sh -f $WVS_ROOT/ifix/LI70692/stopVoiceServer.jacl $thisHostname
      
      cp -fp $WVS_ROOT/ifix/LI70692/wvsapp.ear.bak $WVS_ROOT/ear/wvsapp.ear

      echo "ifixLI70692: Updating WebSphere Voice Server J2EE Application"
      $WAS_HOME/bin/wsadmin.sh -f $WVS_ROOT/.package/installEar.jacl $WVS_ROOT/ear wvsapp WVS5.1-$thisHostname $thisHostname
      errorsduringinstall=$?
      
      if [ $errorsduringinstall = "0" ] ; then
        echo " "
        echo " "
        echo " "
        echo "Ifix_LI70692: Ifix is now uninstalled, please reboot the system"
        echo "Ifix_LI70692:  Please remove the $WVS_ROOT/ifix/LI70692 directory before attempting a subsequent install of this ifix."
        echo " "
      else
        echo " "
        echo " "
        echo " "
        echo "Ifix_LI70692: Ifix uninstallation was not successful. Please contact support. "
        echo " "
      fi
  else
    echo " "
    echo "ifixLI70692: Ifix backup files missing, uninstall not performed"
  fi
fi

exit $?
